[][src]Enum devicemapper::ThinPoolStatus

pub enum ThinPoolStatus {
    Working(Box<ThinPoolWorkingStatus>),
    Error,
    Fail,
}

Top-level thinpool status that indicates if it is working or failed.

Variants

The thinpool has not failed utterly.

Error

Devicemapper has reported that it could not obtain the status

Fail

The thinpool is in a failed condition.