pub enum ThinPoolStatusSummary {
    Good,
    ReadOnly,
    OutOfSpace,
}
Indicates if a working thinpool is working optimally, or is experiencing a non-fatal error condition.

Variants



Good

The pool is working normally.



ReadOnly

The pool has been forced to transition to read-only mode.



OutOfSpace

The pool is out of space.