Enum devicemapper::ThinStatus
source · pub enum ThinStatus {
Working(Box<ThinDevWorkingStatus>),
Error,
Fail,
}Expand description
Thin device status.
Variants
Working(Box<ThinDevWorkingStatus>)
Thin device is good. Includes number of mapped sectors, and highest mapped sector.
Error
Devicemapper has reported that it could not obtain the status
Fail
Thin device is failed.