Function devicemapper::device_exists
source · pub fn device_exists(dm: &DM, name: &DmName) -> DmResult<bool>Expand description
Check if a device of the given name exists.
pub fn device_exists(dm: &DM, name: &DmName) -> DmResult<bool>Check if a device of the given name exists.