Function devicemapper::devnode_to_devno
source · [−]Expand description
Get a device number from a device node. Return None if the device is not a block device; devicemapper is not interested in other sorts of devices. Return None if the device appears not to exist.