Struct Bytes

pub struct Bytes(pub u128);
A type for bytes

Tuple Fields

0: u128

Implementations

Source

impl Bytes

pub fn checked_add(&self, other: Bytes) -> Option<Bytes>

Add two items of the same type, return None if overflow.

Source

impl Bytes

pub fn sectors(self) -> Sectors

Return the number of Sectors fully contained in these bytes.

Methods from Deref<Target = u128>

1.43.0 · Source

pub const MIN: u128 = 0u128

1.43.0 · Source

pub const MAX: u128 = 340_282_366_920_938_463_463_374_607_431_768_211_455u128

1.53.0 · Source

pub const BITS: u32 = 128u32