Struct devicemapper::CacheDev

source ·
pub struct CacheDev { /* private fields */ }
DM Cache device

Implementations

source

impl CacheDev

Cache device implementation.

source

pub fn new( dm: &DM, name: &DmName, uuid: Option<&DmUuid>, meta: LinearDev, cache: LinearDev, origin: LinearDev, cache_block_size: Sectors ) -> DmResult<CacheDev>

Construct a new CacheDev with the given data and meta devs. Returns an error if the device is already known to the kernel.

source

pub fn setup( dm: &DM, name: &DmName, uuid: Option<&DmUuid>, meta: LinearDev, cache: LinearDev, origin: LinearDev, cache_block_size: Sectors ) -> DmResult<CacheDev>

Set up a cache device from the given metadata and data devices.

source

pub fn set_origin_table( &mut self, dm: &DM, table: Vec<TargetLine<LinearDevTargetParams>> ) -> DmResult<()>

Set the table for the existing origin device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated table is compatible with the device’s existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

source

pub fn set_cache_table( &mut self, dm: &DM, table: Vec<TargetLine<LinearDevTargetParams>> ) -> DmResult<()>

Set the table for the existing cache sub-device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated table is compatible with the device’s existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

source

pub fn set_meta_table( &mut self, dm: &DM, table: Vec<TargetLine<LinearDevTargetParams>> ) -> DmResult<()>

Set the table for the existing meta sub-device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated table is compatible with the device’s existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

source

pub fn status(&self, dm: &DM, options: DmOptions) -> DmResult<CacheDevStatus>

Get the current status of the cache device.