Struct devicemapper::CacheDevUsage
source · pub struct CacheDevUsage {
pub meta_block_size: Sectors,
pub used_meta: MetaBlocks,
pub total_meta: MetaBlocks,
pub cache_block_size: Sectors,
pub used_cache: DataBlocks,
pub total_cache: DataBlocks,
}Expand description
Cache usage
Fields
meta_block_size: SectorsThe metadata block size, should always be equal to META_BLOCK_SIZE. At time of writing, all metadata blocks have the same size.
used_meta: MetaBlocksThe number of metadata blocks in use
total_meta: MetaBlocksThe number of metadata blocks available
cache_block_size: SectorsThe cache block size
used_cache: DataBlocksUsed cache blocks
total_cache: DataBlocksTotal cache blocks
Implementations
sourceimpl CacheDevUsage
impl CacheDevUsage
sourcepub fn new(
meta_block_size: Sectors,
used_meta: MetaBlocks,
total_meta: MetaBlocks,
cache_block_size: Sectors,
used_cache: DataBlocks,
total_cache: DataBlocks
) -> CacheDevUsage
pub fn new( meta_block_size: Sectors, used_meta: MetaBlocks, total_meta: MetaBlocks, cache_block_size: Sectors, used_cache: DataBlocks, total_cache: DataBlocks ) -> CacheDevUsage
Make a new CacheDevUsage struct