Struct devicemapper::DmFlags

source ·
pub struct DmFlags(/* private fields */);
Flags used by devicemapper.

Implementations

source

impl DmFlags

source

pub const DM_READONLY: Self = _

In: Device should be read-only. Out: Device is read-only.

source

pub const DM_SUSPEND: Self = _

In: Device should be suspended. Out: Device is suspended.

source

pub const DM_PERSISTENT_DEV: Self = _

In: Use passed-in minor number.

source

pub const DM_STATUS_TABLE: Self = _

In: STATUS command returns table info instead of status.

source

pub const DM_ACTIVE_PRESENT: Self = _

Out: Active table is present.

source

pub const DM_INACTIVE_PRESENT: Self = _

Out: Inactive table is present.

source

pub const DM_BUFFER_FULL: Self = _

Out: Passed-in buffer was too small.

source

pub const DM_SKIP_BDGET: Self = _

Obsolete.

source

pub const DM_SKIP_LOCKFS: Self = _

In: Avoid freezing filesystem when suspending.

source

pub const DM_NOFLUSH: Self = _

In: Suspend without flushing queued I/Os.

source

pub const DM_QUERY_INACTIVE_TABLE: Self = _

In: Query inactive table instead of active.

source

pub const DM_UEVENT_GENERATED: Self = _

Out: A uevent was generated, the caller may need to wait for it.

source

pub const DM_UUID: Self = _

In: Rename affects UUID field, not name field.

source

pub const DM_SECURE_DATA: Self = _

In: All buffers are wiped after use. Use when handling crypto keys.

source

pub const DM_DATA_OUT: Self = _

Out: A message generated output data.

source

pub const DM_DEFERRED_REMOVE: Self = _

In: Do not remove in-use devices. Out: Device scheduled to be removed when closed.

source

pub const DM_INTERNAL_SUSPEND: Self = _

Out: Device is suspended internally.

source

impl DmFlags

source

pub const fn empty() -> Self

Get a flags value with all bits unset.

source

pub const fn all() -> Self

Get a flags value with all known bits set.

source

pub const fn bits(&self) -> __u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

source

pub const fn from_bits(bits: __u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

source

pub const fn from_bits_truncate(bits: __u32) -> Self

Convert from a bits value, unsetting any unknown bits.

source

pub const fn from_bits_retain(bits: __u32) -> Self

Convert from a bits value exactly.

source

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

source

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

source

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

source

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

source

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

source

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

source

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

source

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

source

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

source

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

source

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

source

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

source

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

source

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

source

impl DmFlags

source

pub const fn iter(&self) -> Iter<DmFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

source

pub const fn iter_names(&self) -> IterNames<DmFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.