Struct devicemapper::DmOptions
[−]
[src]
pub struct DmOptions { /* fields omitted */ }Encapsulates options for device mapper calls
Methods
impl DmOptions[src]
pub fn new() -> DmOptions[src]
Create a new empty option
pub fn set_flags(&mut self, flags: DmFlags) -> &mut DmOptions[src]
Set the DmFlags value for option. Note this call is not additive in that it sets (replaces) entire flag value in one call. Thus if you want to incrementally add additional flags you need to retrieve current and '|' with new.
use devicemapper::DmFlags; use devicemapper::DmOptions; let mut options = DmOptions::new(); options.set_flags(DmFlags::DM_READONLY); let flags = DmFlags::DM_PERSISTENT_DEV | options.flags(); options.set_flags(flags);
[src]
Set the cookie bitfield value for option (overloaded meaning with event_nr in header). Note this call is not additive in that it sets (replaces) entire cookie value in one call. Thus if you want to incrementally add additional flags you need to retrieve current and '|' with new.
use devicemapper::{DmCookie, DmFlags}; use devicemapper::DmOptions; let mut options = DmOptions::new(); options.set_cookie(DmCookie::DM_UDEV_PRIMARY_SOURCE_FLAG); let new_cookie = options.cookie() | DmCookie::DM_UDEV_DISABLE_DM_RULES_FLAG; options.set_cookie(new_cookie);
pub fn flags(&self) -> DmFlags[src]
Retrieve the flags value
[src]
Retrieve the cookie value (used for input in upper 16 bits of event_nr header field).