Struct devicemapper::DmUdevFlags
source · pub struct DmUdevFlags { /* private fields */ }Expand description
Flags used by devicemapper, see: https://sourceware.org/git/?p=lvm2.git;a=blob;f=libdm/libdevmapper.h#l3627 for complete information about the meaning of the flags.
Implementations
sourceimpl DmUdevFlags
impl DmUdevFlags
sourcepub const DM_UDEV_DISABLE_DM_RULES_FLAG: Self = _
pub const DM_UDEV_DISABLE_DM_RULES_FLAG: Self = _
Disables basic device-mapper udev rules that create symlinks in /dev/<DM_DIR> directory.
sourcepub const DM_UDEV_DISABLE_SUBSYSTEM_RULES_FLAG: Self = _
pub const DM_UDEV_DISABLE_SUBSYSTEM_RULES_FLAG: Self = _
Disable subsystem udev rules, but allow general DM udev rules to run.
sourcepub const DM_UDEV_DISABLE_DISK_RULES_FLAG: Self = _
pub const DM_UDEV_DISABLE_DISK_RULES_FLAG: Self = _
Disable dm udev rules which create symlinks in /dev/disk/* directory.
sourcepub const DM_UDEV_DISABLE_OTHER_RULES_FLAG: Self = _
pub const DM_UDEV_DISABLE_OTHER_RULES_FLAG: Self = _
Disable all rules that are not general dm nor subsystem related.
sourcepub const DM_UDEV_LOW_PRIORITY_FLAG: Self = _
pub const DM_UDEV_LOW_PRIORITY_FLAG: Self = _
Instruct udev rules to give lower priority to the device.
sourcepub const DM_UDEV_DISABLE_LIBRARY_FALLBACK: Self = _
pub const DM_UDEV_DISABLE_LIBRARY_FALLBACK: Self = _
Disable libdevmapper’s node management.
sourcepub const DM_UDEV_PRIMARY_SOURCE_FLAG: Self = _
pub const DM_UDEV_PRIMARY_SOURCE_FLAG: Self = _
Automatically appended to all IOCTL calls issues by libdevmapper for generating udev uevents.
sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Self
pub const unsafe fn from_bits_unchecked(bits: u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.