Struct FlakeyTargetParams

pub struct FlakeyTargetParams {
    pub device: Device,
    pub start_offset: Sectors,
    pub up_interval: u32,
    pub down_interval: u32,
    pub feature_args: HashSet<FeatureArg>,
}
Target params for flakey target

Fields

device: Device

The device on which this segment resides

start_offset: Sectors

The starting offset of this segments in the device.

up_interval: u32

Interval during which flakey target is up, in seconds DM source type is unsigned, so restrict to u32.

down_interval: u32

Interval during which flakey target is down, in seconds DM source type is unsigned, so restrict to u32.

feature_args: HashSet<FeatureArg>

Optional feature arguments

Implementations

Source

impl FlakeyTargetParams

pub fn new( device: Device, start_offset: Sectors, up_interval: u32, down_interval: u32, feature_args: Vec<FeatureArg>, ) -> FlakeyTargetParams

Create a new flakey target param struct.