Struct devicemapper::MetaBlocks
source · pub struct MetaBlocks(pub u64);Expand description
A type for Meta Data blocks as used by the thin pool. MetaBlocks have a kernel defined constant size of META_BLOCK_SIZE
Tuple Fields
0: u64Implementations
sourceimpl MetaBlocks
impl MetaBlocks
Methods from Deref<Target = u64>