pub struct Sectors(pub u64);Expand description
A type for sectors
Tuple Fields
0: u64Implementations
Sourceimpl Sectors
impl Sectors
Sourcepub fn checked_add(&self, other: Sectors) -> Option<Sectors>
pub fn checked_add(&self, other: Sectors) -> Option<Sectors>
Add two items of the same type, return None if overflow.
Sourceimpl Sectors
impl Sectors
Sourcepub fn metablocks(self) -> MetaBlocks
pub fn metablocks(self) -> MetaBlocks
The number of whole metablocks contained in these sectors.