[][src]Struct devicemapper::ThinDevId

pub struct ThinDevId { /* fields omitted */ }

A thindev id is a 24 bit number, i.e., its bit width is not a power of 2.

Implementations

impl ThinDevId[src]

pub fn new_u64(value: u64) -> DmResult<ThinDevId>[src]

Make a new ThinDevId. Return an error if value is too large to represent in 24 bits.