Struct devicemapper::ThinPoolUsage
source · pub struct ThinPoolUsage {
pub used_meta: MetaBlocks,
pub total_meta: MetaBlocks,
pub used_data: DataBlocks,
pub total_data: DataBlocks,
}Expand description
Contains values indicating the thinpool’s used vs total allocations for metadata and data blocks.
Fields
used_meta: MetaBlocksThe number of metadata blocks that are in use.
total_meta: MetaBlocksThe total number of metadata blocks available to the thinpool.
used_data: DataBlocksThe number of data blocks that are in use.
total_data: DataBlocksThe total number of data blocks available to the thinpool.