Struct devicemapper::ThinPoolWorkingStatus [−][src]
pub struct ThinPoolWorkingStatus {
pub transaction_id: u64,
pub usage: ThinPoolUsage,
pub held_metadata_root: Option<MetaBlocks>,
pub discard_passdown: bool,
pub no_space_policy: ThinPoolNoSpacePolicy,
pub summary: ThinPoolStatusSummary,
pub needs_check: bool,
pub meta_low_water: Option<u64>,
}Expand description
Status of a working thin pool, i.e, one that does not have status Fail
Fields
transaction_id: u64The transaction id.
usage: ThinPoolUsageA struct recording block usage for meta and data devices.
held_metadata_root: Option<MetaBlocks>A single block value indicating the held metadata root
discard_passdown: booldiscard_passdown/no_discard_passdown
no_space_policy: ThinPoolNoSpacePolicyno space policy
summary: ThinPoolStatusSummaryA summary of some other status information.
needs_check: boolneeds_check flag has been set in metadata superblock
meta_low_water: Option<u64>The lowater value for the metadata device in metablocks. This value is set by the kernel. Available in kernel version 4.19 and later.
Implementations
pub fn new(
transaction_id: u64,
usage: ThinPoolUsage,
held_metadata_root: Option<MetaBlocks>,
discard_passdown: bool,
no_space_policy: ThinPoolNoSpacePolicy,
summary: ThinPoolStatusSummary,
needs_check: bool,
meta_low_water: Option<u64>
) -> ThinPoolWorkingStatus
pub fn new(
transaction_id: u64,
usage: ThinPoolUsage,
held_metadata_root: Option<MetaBlocks>,
discard_passdown: bool,
no_space_policy: ThinPoolNoSpacePolicy,
summary: ThinPoolStatusSummary,
needs_check: bool,
meta_low_water: Option<u64>
) -> ThinPoolWorkingStatusMake a new ThinPoolWorkingStatus struct