Struct devicemapper::CacheDev

source ·
pub struct CacheDev { /* private fields */ }
DM Cache device

Implementations

Cache device implementation.

Construct a new CacheDev with the given data and meta devs. Returns an error if the device is already known to the kernel.

Set up a cache device from the given metadata and data devices.

Set the table for the existing origin device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated table is compatible with the device’s existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

Set the table for the existing cache sub-device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated table is compatible with the device’s existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

Set the table for the existing meta sub-device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated table is compatible with the device’s existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

Get the current status of the cache device.