Struct devicemapper::CacheDev [] [src]

pub struct CacheDev { /* fields omitted */ }

DM Cache device

Methods

impl CacheDev
[src]

Cache device implementation.

[src]

Construct a new CacheDev with the given data and meta devs. Returns an error if the device is already known to the kernel.

[src]

Set up a cache device from the given metadata and data devices.

[src]

Set the table for the existing origin device. Warning: It is the client's responsibility to make sure the designated table is compatible with the device's existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.

[src]

Get the current status of the cache device.