Struct devicemapper::CacheDevUsage [] [src]

pub struct CacheDevUsage {
    pub meta_block_size: Sectors,
    pub used_meta: MetaBlocks,
    pub total_meta: MetaBlocks,
    pub cache_block_size: Sectors,
    pub used_cache: DataBlocks,
    pub total_cache: DataBlocks,
}

Cache usage

Fields

The metadata block size, should always be equal to META_BLOCK_SIZE. At time of writing, all metadata blocks have the same size.

The number of metadata blocks in use

The number of metadata blocks available

The cache block size

Used cache blocks

Total cache blocks

Methods

impl CacheDevUsage
[src]

[src]

Make a new CacheDevUsage struct