Struct devicemapper::DeviceInfo
source · pub struct DeviceInfo { /* private fields */ }Expand description
Contains information about the device.
Implementations
sourceimpl DeviceInfo
impl DeviceInfo
sourcepub fn new(hdr: Struct_dm_ioctl) -> DmResult<Self>
pub fn new(hdr: Struct_dm_ioctl) -> DmResult<Self>
Parses a DM ioctl structure.
Equivalent to DeviceInfo::try_from(hdr).
Examples found in repository?
src/core/dm.rs (line 153)
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181
fn do_ioctl(
&self,
ioctl: u8,
hdr: &mut dmi::Struct_dm_ioctl,
in_data: Option<&[u8]>,
) -> DmResult<(DeviceInfo, Vec<u8>)> {
let op = request_code_readwrite!(dmi::DM_IOCTL, ioctl, size_of::<dmi::Struct_dm_ioctl>());
#[cfg(target_os = "android")]
let op = op as i32;
let ioctl_version = dmi::ioctl_to_version(ioctl);
hdr.version[0] = ioctl_version.0;
hdr.version[1] = ioctl_version.1;
hdr.version[2] = ioctl_version.2;
let data_size = cmp::max(
MIN_BUF_SIZE,
size_of::<dmi::Struct_dm_ioctl>() + in_data.map_or(0, |x| x.len()),
);
let mut buffer: Vec<u8> = Vec::with_capacity(data_size);
let mut buffer_hdr;
loop {
hdr.data_size = buffer.capacity() as u32;
let hdr_slc = unsafe {
let len = hdr.data_start as usize;
let ptr = hdr as *mut dmi::Struct_dm_ioctl as *mut u8;
slice::from_raw_parts_mut(ptr, len)
};
buffer.clear();
buffer.extend_from_slice(hdr_slc);
if let Some(in_data) = in_data {
buffer.extend(in_data.iter().cloned());
}
buffer.resize(buffer.capacity(), 0);
buffer_hdr = unsafe { &mut *(buffer.as_mut_ptr() as *mut dmi::Struct_dm_ioctl) };
if let Err(err) = unsafe {
convert_ioctl_res!(nix_ioctl(self.file.as_raw_fd(), op, buffer.as_mut_ptr()))
} {
return Err(DmError::Core(errors::Error::Ioctl(
op as u8,
DeviceInfo::new(*hdr).ok().map(Box::new),
DeviceInfo::new(*buffer_hdr).ok().map(Box::new),
Box::new(err),
)));
}
if (buffer_hdr.flags & DmFlags::DM_BUFFER_FULL.bits()) == 0 {
break;
}
// If DM_BUFFER_FULL is set, DM requires more space for the
// response. Double the capacity of the buffer and re-try the
// ioctl. If the size of the buffer is already as large as can be
// possibly expressed in data_size field, return an error.
// Never allow the size to exceed u32::MAX.
let len = buffer.capacity();
if len == u32::MAX as usize {
return Err(DmError::Core(errors::Error::IoctlResultTooLarge));
}
buffer.resize((len as u32).saturating_mul(2) as usize, 0);
}
let data_end = cmp::max(buffer_hdr.data_size, buffer_hdr.data_start);
Ok((
DeviceInfo::try_from(*buffer_hdr)?,
buffer[buffer_hdr.data_start as usize..data_end as usize].to_vec(),
))
}sourcepub fn version(&self) -> &Version
pub fn version(&self) -> &Version
The major, minor, and patchlevel versions of devicemapper.
Examples found in repository?
src/core/dm.rs (line 191)
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291
pub fn version(&self) -> DmResult<(u32, u32, u32)> {
let mut hdr = DmOptions::default().to_ioctl_hdr(None, DmFlags::empty())?;
let (hdr_out, _) = self.do_ioctl(dmi::DM_VERSION_CMD as u8, &mut hdr, None)?;
Ok((
hdr_out
.version()
.major
.try_into()
.expect("dm_ioctl struct field is u32"),
hdr_out
.version()
.minor
.try_into()
.expect("dm_ioctl struct field is u32"),
hdr_out
.version()
.patch
.try_into()
.expect("dm_ioctl struct field is u32"),
))
}
/// Remove all DM devices and tables. Use discouraged other than
/// for debugging.
///
/// If `DM_DEFERRED_REMOVE` is set, the request will succeed for
/// in-use devices, and they will be removed when released.
///
/// Valid flags: `DM_DEFERRED_REMOVE`
pub fn remove_all(&self, options: DmOptions) -> DmResult<()> {
let mut hdr = options.to_ioctl_hdr(None, DmFlags::DM_DEFERRED_REMOVE)?;
self.do_ioctl(dmi::DM_REMOVE_ALL_CMD as u8, &mut hdr, None)?;
Ok(())
}
/// Returns a list of tuples containing DM device names, a Device, which
/// holds their major and minor device numbers, and on kernels that
/// support it, each device's last event_nr.
pub fn list_devices(&self) -> DmResult<Vec<(DmNameBuf, Device, Option<u32>)>> {
let mut hdr = DmOptions::default().to_ioctl_hdr(None, DmFlags::empty())?;
let (hdr_out, data_out) = self.do_ioctl(dmi::DM_LIST_DEVICES_CMD as u8, &mut hdr, None)?;
let event_nr_set = hdr_out.version() >= &Version::new(4, 37, 0);
let mut devs = Vec::new();
if !data_out.is_empty() {
let mut result = &data_out[..];
loop {
let device =
c_struct_from_slice::<dmi::Struct_dm_name_list>(result).ok_or_else(|| {
DmError::Dm(
ErrorEnum::Invalid,
"Received null pointer from kernel".to_string(),
)
})?;
let name_offset = unsafe {
(device.name.as_ptr() as *const u8).offset_from(device as *const _ as *const u8)
} as usize;
let dm_name = str_from_byte_slice(&result[name_offset..])
.map(|s| s.to_owned())
.ok_or_else(|| {
DmError::Dm(
ErrorEnum::Invalid,
"Devicemapper name is not valid UTF8".to_string(),
)
})?;
// Get each device's event number after its name, if the kernel
// DM version supports it.
// Should match offset calc in kernel's
// drivers/md/dm-ioctl.c:list_devices
let event_nr = if event_nr_set {
// offsetof "name" in Struct_dm_name_list.
let offset = align_to(name_offset + dm_name.len() + 1, size_of::<u64>());
let nr = u32::from_ne_bytes(
result[offset..offset + size_of::<u32>()]
.try_into()
.map_err(|_| {
DmError::Dm(
ErrorEnum::Invalid,
"Incorrectly sized slice for u32".to_string(),
)
})?,
);
Some(nr)
} else {
None
};
devs.push((DmNameBuf::new(dm_name)?, device.dev.into(), event_nr));
if device.next == 0 {
break;
}
result = &result[device.next as usize..];
}
}
Ok(devs)
}sourcepub fn open_count(&self) -> i32
pub fn open_count(&self) -> i32
The number of times the device is currently open.
sourcepub fn flags(&self) -> DmFlags
pub fn flags(&self) -> DmFlags
The flags returned from the device.
Examples found in repository?
src/core/dm.rs (line 708)
685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723
pub fn target_msg(
&self,
id: &DevId<'_>,
sector: Option<u64>,
msg: &str,
) -> DmResult<(DeviceInfo, Option<String>)> {
let mut hdr = DmOptions::default().to_ioctl_hdr(Some(id), DmFlags::empty())?;
let msg_struct = dmi::Struct_dm_target_msg {
sector: sector.unwrap_or_default(),
..Default::default()
};
let mut data_in = unsafe {
let ptr = &msg_struct as *const dmi::Struct_dm_target_msg as *mut u8;
slice::from_raw_parts(ptr, size_of::<dmi::Struct_dm_target_msg>()).to_vec()
};
data_in.extend(msg.as_bytes());
data_in.push(b'\0');
let (hdr_out, data_out) =
self.do_ioctl(dmi::DM_TARGET_MSG_CMD as u8, &mut hdr, Some(&data_in))?;
let output = if (hdr_out.flags().bits() & DmFlags::DM_DATA_OUT.bits()) > 0 {
Some(
str::from_utf8(&data_out[..data_out.len() - 1])
.map(|res| res.to_string())
.map_err(|_| {
DmError::Dm(
ErrorEnum::Invalid,
"Could not convert output to a String".to_string(),
)
})?,
)
} else {
None
};
Ok((hdr_out, output))
}Trait Implementations
sourceimpl Clone for DeviceInfo
impl Clone for DeviceInfo
sourcefn clone(&self) -> DeviceInfo
fn clone(&self) -> DeviceInfo
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more