Struct devicemapper::DmFlags
source · pub struct DmFlags(/* private fields */);Expand description
Flags used by devicemapper.
Implementations
sourceimpl DmFlags
impl DmFlags
sourcepub const DM_READONLY: Self = _
pub const DM_READONLY: Self = _
In: Device should be read-only. Out: Device is read-only.
sourcepub const DM_SUSPEND: Self = _
pub const DM_SUSPEND: Self = _
In: Device should be suspended. Out: Device is suspended.
sourcepub const DM_PERSISTENT_DEV: Self = _
pub const DM_PERSISTENT_DEV: Self = _
In: Use passed-in minor number.
sourcepub const DM_STATUS_TABLE: Self = _
pub const DM_STATUS_TABLE: Self = _
In: STATUS command returns table info instead of status.
sourcepub const DM_ACTIVE_PRESENT: Self = _
pub const DM_ACTIVE_PRESENT: Self = _
Out: Active table is present.
sourcepub const DM_INACTIVE_PRESENT: Self = _
pub const DM_INACTIVE_PRESENT: Self = _
Out: Inactive table is present.
sourcepub const DM_BUFFER_FULL: Self = _
pub const DM_BUFFER_FULL: Self = _
Out: Passed-in buffer was too small.
sourcepub const DM_SKIP_BDGET: Self = _
pub const DM_SKIP_BDGET: Self = _
Obsolete.
sourcepub const DM_SKIP_LOCKFS: Self = _
pub const DM_SKIP_LOCKFS: Self = _
In: Avoid freezing filesystem when suspending.
sourcepub const DM_NOFLUSH: Self = _
pub const DM_NOFLUSH: Self = _
In: Suspend without flushing queued I/Os.
sourcepub const DM_QUERY_INACTIVE_TABLE: Self = _
pub const DM_QUERY_INACTIVE_TABLE: Self = _
In: Query inactive table instead of active.
sourcepub const DM_UEVENT_GENERATED: Self = _
pub const DM_UEVENT_GENERATED: Self = _
Out: A uevent was generated, the caller may need to wait for it.
sourcepub const DM_SECURE_DATA: Self = _
pub const DM_SECURE_DATA: Self = _
In: All buffers are wiped after use. Use when handling crypto keys.
sourcepub const DM_DATA_OUT: Self = _
pub const DM_DATA_OUT: Self = _
Out: A message generated output data.
sourcepub const DM_DEFERRED_REMOVE: Self = _
pub const DM_DEFERRED_REMOVE: Self = _
In: Do not remove in-use devices. Out: Device scheduled to be removed when closed.
sourcepub const DM_INTERNAL_SUSPEND: Self = _
pub const DM_INTERNAL_SUSPEND: Self = _
Out: Device is suspended internally.
sourceimpl DmFlags
impl DmFlags
sourcepub const fn bits(&self) -> __u32
pub const fn bits(&self) -> __u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
sourcepub const fn from_bits(bits: __u32) -> Option<Self>
pub const fn from_bits(bits: __u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
sourcepub const fn from_bits_truncate(bits: __u32) -> Self
pub const fn from_bits_truncate(bits: __u32) -> Self
Convert from a bits value, unsetting any unknown bits.
sourcepub const fn from_bits_retain(bits: __u32) -> Self
pub const fn from_bits_retain(bits: __u32) -> Self
Convert from a bits value exactly.
sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
sourceimpl DmFlags
impl DmFlags
sourcepub const fn iter(&self) -> Iter<DmFlags>
pub const fn iter(&self) -> Iter<DmFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
sourcepub const fn iter_names(&self) -> IterNames<DmFlags>
pub const fn iter_names(&self) -> IterNames<DmFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.