Struct devicemapper::DmFlags
source · pub struct DmFlags { /* private fields */ }Expand description
Flags used by devicemapper.
Implementations
sourceimpl DmFlags
impl DmFlags
sourcepub const DM_READONLY: Self = _
pub const DM_READONLY: Self = _
In: Device should be read-only. Out: Device is read-only.
sourcepub const DM_SUSPEND: Self = _
pub const DM_SUSPEND: Self = _
In: Device should be suspended. Out: Device is suspended.
sourcepub const DM_PERSISTENT_DEV: Self = _
pub const DM_PERSISTENT_DEV: Self = _
In: Use passed-in minor number.
sourcepub const DM_STATUS_TABLE: Self = _
pub const DM_STATUS_TABLE: Self = _
In: STATUS command returns table info instead of status.
sourcepub const DM_ACTIVE_PRESENT: Self = _
pub const DM_ACTIVE_PRESENT: Self = _
Out: Active table is present.
sourcepub const DM_INACTIVE_PRESENT: Self = _
pub const DM_INACTIVE_PRESENT: Self = _
Out: Inactive table is present.
sourcepub const DM_BUFFER_FULL: Self = _
pub const DM_BUFFER_FULL: Self = _
Out: Passed-in buffer was too small.
sourcepub const DM_SKIP_BDGET: Self = _
pub const DM_SKIP_BDGET: Self = _
Obsolete.
sourcepub const DM_SKIP_LOCKFS: Self = _
pub const DM_SKIP_LOCKFS: Self = _
In: Avoid freezing filesystem when suspending.
sourcepub const DM_NOFLUSH: Self = _
pub const DM_NOFLUSH: Self = _
In: Suspend without flushing queued I/Os.
sourcepub const DM_QUERY_INACTIVE_TABLE: Self = _
pub const DM_QUERY_INACTIVE_TABLE: Self = _
In: Query inactive table instead of active.
sourcepub const DM_UEVENT_GENERATED: Self = _
pub const DM_UEVENT_GENERATED: Self = _
Out: A uevent was generated, the caller may need to wait for it.
sourcepub const DM_SECURE_DATA: Self = _
pub const DM_SECURE_DATA: Self = _
In: All buffers are wiped after use. Use when handling crypto keys.
sourcepub const DM_DATA_OUT: Self = _
pub const DM_DATA_OUT: Self = _
Out: A message generated output data.
sourcepub const DM_DEFERRED_REMOVE: Self = _
pub const DM_DEFERRED_REMOVE: Self = _
In: Do not remove in-use devices. Out: Device scheduled to be removed when closed.
sourcepub const DM_INTERNAL_SUSPEND: Self = _
pub const DM_INTERNAL_SUSPEND: Self = _
Out: Device is suspended internally.
sourcepub const fn from_bits(bits: __u32) -> Option<Self>
pub const fn from_bits(bits: __u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: __u32) -> Self
pub const fn from_bits_truncate(bits: __u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: __u32) -> Self
pub const unsafe fn from_bits_unchecked(bits: __u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.