Struct devicemapper::DmFlags
[−]
pub struct DmFlags { /* fields omitted */ }Flags used by devicemapper.
Methods
impl DmFlags
const DM_READONLY: DmFlags
DM_READONLY: DmFlags = DmFlags{bits: 1 << 0,}
In: Device should be read-only. Out: Device is read-only.
const DM_SUSPEND: DmFlags
DM_SUSPEND: DmFlags = DmFlags{bits: 1 << 1,}
In: Device should be suspended. Out: Device is suspended.
const DM_PERSISTENT_DEV: DmFlags
DM_PERSISTENT_DEV: DmFlags = DmFlags{bits: 1 << 3,}
In: Use passed-in minor number.
const DM_STATUS_TABLE: DmFlags
DM_STATUS_TABLE: DmFlags = DmFlags{bits: 1 << 4,}
In: STATUS command returns table info instead of status.
const DM_ACTIVE_PRESENT: DmFlags
DM_ACTIVE_PRESENT: DmFlags = DmFlags{bits: 1 << 5,}
Out: Active table is present.
const DM_INACTIVE_PRESENT: DmFlags
DM_INACTIVE_PRESENT: DmFlags = DmFlags{bits: 1 << 6,}
Out: Inactive table is present.
const DM_BUFFER_FULL: DmFlags
DM_BUFFER_FULL: DmFlags = DmFlags{bits: 1 << 8,}
Out: Passed-in buffer was too small.
const DM_SKIP_BDGET: DmFlags
DM_SKIP_BDGET: DmFlags = DmFlags{bits: 1 << 9,}
Obsolete.
const DM_SKIP_LOCKFS: DmFlags
DM_SKIP_LOCKFS: DmFlags = DmFlags{bits: 1 << 10,}
In: Avoid freezing filesystem when suspending.
const DM_NOFLUSH: DmFlags
DM_NOFLUSH: DmFlags = DmFlags{bits: 1 << 11,}
In: Suspend without flushing queued I/Os.
const DM_QUERY_INACTIVE_TABLE: DmFlags
DM_QUERY_INACTIVE_TABLE: DmFlags = DmFlags{bits: 1 << 12,}
In: Query inactive table instead of active.
const DM_UEVENT_GENERATED: DmFlags
DM_UEVENT_GENERATED: DmFlags = DmFlags{bits: 1 << 13,}
Out: A uevent was generated, the caller may need to wait for it.
const DM_UUID: DmFlags
DM_UUID: DmFlags = DmFlags{bits: 1 << 14,}
In: Rename affects UUID field, not name field.
const DM_SECURE_DATA: DmFlags
DM_SECURE_DATA: DmFlags = DmFlags{bits: 1 << 15,}
In: All buffers are wiped after use. Use when handling crypto keys.
const DM_DATA_OUT: DmFlags
DM_DATA_OUT: DmFlags = DmFlags{bits: 1 << 16,}
Out: A message generated output data.
const DM_DEFERRED_REMOVE: DmFlags
DM_DEFERRED_REMOVE: DmFlags = DmFlags{bits: 1 << 17,}
In: Do not remove in-use devices. Out: Device scheduled to be removed when closed.
const DM_INTERNAL_SUSPEND: DmFlags
DM_INTERNAL_SUSPEND: DmFlags = DmFlags{bits: 1 << 18,}
Out: Device is suspended internally.
fn empty() -> DmFlags
Returns an empty set of flags.
fn all() -> DmFlags
Returns the set containing all flags.
fn bits(&self) -> c_uint
Returns the raw value of the flags currently stored.
fn from_bits(bits: c_uint) -> Option<DmFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: c_uint) -> DmFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: DmFlags) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: DmFlags) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: DmFlags)
Inserts the specified flags in-place.
fn remove(&mut self, other: DmFlags)
Removes the specified flags in-place.
fn toggle(&mut self, other: DmFlags)
Toggles the specified flags in-place.
fn set(&mut self, other: DmFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.