Struct devicemapper::LinearDev
source · pub struct LinearDev { /* private fields */ }Expand description
A DM construct of combined Segments
Implementations
sourceimpl LinearDev
impl LinearDev
Use DM to concatenate a list of segments together into a linear block device of continuous sectors.
sourcepub fn setup(
dm: &DM,
name: &DmName,
uuid: Option<&DmUuid>,
table: Vec<TargetLine<LinearDevTargetParams>>
) -> DmResult<LinearDev>
pub fn setup( dm: &DM, name: &DmName, uuid: Option<&DmUuid>, table: Vec<TargetLine<LinearDevTargetParams>> ) -> DmResult<LinearDev>
Construct a new block device by concatenating the given segments into linear space. If the device is already known to the kernel, just verifies that the segments argument passed exactly matches the kernel data.
Warning: If the segments overlap, this method will succeed. However, the behavior of the linear device in that case should be treated as undefined.
Note: A linear device is just a mapping in the kernel from locations in that device to locations on other devices which are specified by their device number. There is usually a device node so that data can be read from and written to the device. Other than that, it really has no existence. Consequently, there is no conflict in overloading this method to mean both “make a wholly new device” and “establish the existence of the requested device”. Of course, a linear device is usually expected to hold data, so it is important to get the mapping just right.
sourcepub fn set_table(
&mut self,
dm: &DM,
table: Vec<TargetLine<LinearDevTargetParams>>
) -> DmResult<()>
pub fn set_table( &mut self, dm: &DM, table: Vec<TargetLine<LinearDevTargetParams>> ) -> DmResult<()>
Set the segments for this linear device. This action puts the device in a state where it is ready to be resumed. Warning: It is the client’s responsibility to make sure the designated segments are compatible with the device’s existing segments. If they are not, this function will still succeed, but some kind of data corruption will be the inevitable result.