Struct devicemapper::LinearDev [] [src]

pub struct LinearDev {
    pub dev_info: DeviceInfo,
}

A DM construct of combined Segments

Fields

Data about the device

Methods

impl LinearDev
[src]

Use DM to concatenate a set of blockdevs together into a /dev/mapper/xxx block device of continuous sectors.

Construct a new block device by concatenating the given block_devs into linear space. Use DM to reserve enough space for the stratis metadata on each DmDev.

DM name - from the DeviceInfo struct

Get the "x:y" device string for this LinearDev

return the total size of the linear device

path of the device node

Remove the device from DM