Struct devicemapper::LinearDev
[−]
[src]
pub struct LinearDev {
pub dev_info: DeviceInfo,
}A DM construct of combined Segments
Fields
dev_info: DeviceInfo
Data about the device
Methods
impl LinearDev[src]
Use DM to concatenate a set of blockdevs together into a /dev/mapper/xxx block device of continuous sectors.
fn new(name: &str, dm: &DM, block_devs: &[Segment]) -> DmResult<LinearDev>
Construct a new block device by concatenating the given block_devs into linear space. Use DM to reserve enough space for the stratis metadata on each DmDev.
fn name(&self) -> &str
DM name - from the DeviceInfo struct
fn dstr(&self) -> String
Get the "x:y" device string for this LinearDev
fn size(&self) -> DmResult<Bytes>
return the total size of the linear device
fn devnode(&self) -> DmResult<PathBuf>
path of the device node
fn teardown(self, dm: &DM) -> DmResult<()>
Remove the device from DM