Struct devicemapper::MetaBlocks
[−]
pub struct MetaBlocks(pub u64);
A type for Meta Data blocks as used by the thin pool. MetaBlocks have a kernel defined constant size of META_BLOCK_SIZE
Methods
impl MetaBlocks[src]
Methods from Deref<Target = u64>