Struct devicemapper::Sectors
source · pub struct Sectors(pub u64);Expand description
A type for sectors
Tuple Fields
0: u64Implementations
sourceimpl Sectors
impl Sectors
sourcepub fn checked_add(&self, other: Sectors) -> Option<Sectors>
pub fn checked_add(&self, other: Sectors) -> Option<Sectors>
Add two items of the same type, return None if overflow.
sourceimpl Sectors
impl Sectors
sourcepub fn metablocks(self) -> MetaBlocks
pub fn metablocks(self) -> MetaBlocks
The number of whole metablocks contained in these sectors.
Methods from Deref<Target = u64>