Struct devicemapper::ThinDevId [−][src]
pub struct ThinDevId { /* fields omitted */ }A thindev id is a 24 bit number, i.e., its bit width is not a power of 2.
Methods
impl ThinDevId[src]
impl ThinDevIdpub fn new_u64(value: u64) -> DmResult<ThinDevId>[src]
pub fn new_u64(value: u64) -> DmResult<ThinDevId>Make a new ThinDevId. Return an error if value is too large to represent in 24 bits.