Struct devicemapper::ThinPoolDev [] [src]

pub struct ThinPoolDev { /* fields omitted */ }

DM construct to contain thin provisioned devices

Methods

impl ThinPoolDev
[src]

Use DM to create a "thin-pool". A "thin-pool" is shared space for other thin provisioned devices to use.

See section "Setting up a fresh pool device": https://www.kernel.org/doc/Documentation/device-mapper/thin-provisioning.txt

[src]

Construct a new ThinPoolDev with the given data and meta devs. Returns an error if the device is already known to the kernel. Returns an error if data_block_size is not within required range. Precondition: the metadata device does not contain any pool metadata.

[src]

Obtain the meta device that backs this thin pool device.

[src]

Obtain the data device that backs this thin pool device.

[src]

Obtain the data block size for this thin pool device.

[src]

Set up a thin pool from the given metadata and data device. Returns an error if data_block_size is not within required range. Precondition: There is existing metadata for this thinpool device on the metadata device. If the metadata is corrupted, subsequent errors will result, so it is expected that the metadata is well-formed and consistent with the data on the data device.

[src]

Get the current status of the thinpool. Returns an error if there was an error getting the status value. Panics if there is an error parsing the status value. Note: Kernel docs show the ordering of the discard_passdown and the summary field opposite to the code below. But this code couldn't pass tests unless it were correct and the kernel docs wrong.

[src]

Set the table for the existing metadata device. Warning: It is the client's responsibility to make sure the designated table is compatible with the device's existing table. If are not, this function will still succeed, but some kind of data corruption will be the inevitable result.

[src]

Set the data device's existing table. Warning: It is the client's responsibility to make sure the designated table is compatible with the device's existing table. If not, this function will still succeed, but some kind of data corruption will be the inevitable result.