Struct devicemapper::ThinPoolWorkingStatus
[−]
[src]
pub struct ThinPoolWorkingStatus {
pub transaction_id: u64,
pub usage: ThinPoolUsage,
pub discard_passdown: bool,
pub no_space_policy: ThinPoolNoSpacePolicy,
pub summary: ThinPoolStatusSummary,
pub needs_check: bool,
}Status of a working thin pool, i.e, one that does not have status Fail Note that this struct is incomplete. It does not contain every value that can be parsed from a data line, as some of those values are of unknown format.
Fields
transaction_id: u64
The transaction id.
usage: ThinPoolUsage
A struct recording block usage for meta and data devices.
discard_passdown: bool
discard_passdown/no_discard_passdown
no_space_policy: ThinPoolNoSpacePolicy
no space policy
summary: ThinPoolStatusSummary
A summary of some other status information.
needs_check: bool
needs_check flag has been set in metadata superblock
Methods
impl ThinPoolWorkingStatus[src]
pub fn new(
transaction_id: u64,
usage: ThinPoolUsage,
discard_passdown: bool,
no_space_policy: ThinPoolNoSpacePolicy,
summary: ThinPoolStatusSummary,
needs_check: bool
) -> ThinPoolWorkingStatus[src]
transaction_id: u64,
usage: ThinPoolUsage,
discard_passdown: bool,
no_space_policy: ThinPoolNoSpacePolicy,
summary: ThinPoolStatusSummary,
needs_check: bool
) -> ThinPoolWorkingStatus
Make a new ThinPoolWorkingStatus struct